@@ -86,7 +86,7 @@ QSize CFreqCtrl::sizeHint() const
     return QSize(100, 20);
 }
 
-bool CFreqCtrl::inRect(QRect &rect, QPoint &point)
+bool CFreqCtrl::inRect(QRect &rect, QPointF &point)
 {
     if ((point.x() < rect.right()) && (point.x() > rect.x()) &&
         (point.y() < rect.bottom()) && (point.y() > rect.y()))
@@ -95,6 +95,33 @@ bool CFreqCtrl::inRect(QRect &rect, QPoint &point)
         return false;
 }
 
+void CFreqCtrl::setActiveDigit(int idx)
+{
+    for (int i = m_DigStart; i < m_NumDigits; i++)
+    {
+        if (i == idx)
+        {
+            if (!m_DigitInfo[i].editmode)
+            {
+                m_DigitInfo[i].editmode = true;
+                m_ActiveEditDigit = i;
+            }
+        }
+        else
+        {
+            // un-highlight the previous digit if moved off it
+            if (m_DigitInfo[i].editmode)
+            {
+                m_DigitInfo[i].editmode = false;
+                m_DigitInfo[i].modified = true;
+            }
+        }
+    }
+
+    updateCtrl(false);
+
+}
+
 static int fmax_to_numdigits(qint64 fmax)
 {
     if (fmax < 10e6)
@@ -349,7 +376,7 @@ void CFreqCtrl::updateCtrl(bool all)
 void CFreqCtrl::resizeEvent(QResizeEvent *)
 {
 // qDebug() <<rect.width() << rect.height();
-    int dpr = devicePixelRatio();
+    qreal dpr = devicePixelRatioF();
     m_Pixmap = QPixmap(width() * dpr, height() * dpr); // resize pixmap to current control size
     m_Pixmap.setDevicePixelRatio(dpr);
     m_Pixmap.fill(m_BkColor);
@@ -390,7 +417,11 @@ void CFreqCtrl::paintEvent(QPaintEvent *)
 
 void CFreqCtrl::mouseMoveEvent(QMouseEvent *event)
 {
-    QPoint    pt = event->pos();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QPointF pt = event->localPos();
+#else
+    QPointF pt = event->position();
+#endif
     // find which digit is to be edited
     if (isActiveWindow())
     {
@@ -401,30 +432,19 @@ void CFreqCtrl::mouseMoveEvent(QMouseEvent *event)
         {
             if (inRect(m_DigitInfo[i].dQRect, pt))
             {
-                if (!m_DigitInfo[i].editmode)
-                {
-                    m_DigitInfo[i].editmode = true;
-                    m_ActiveEditDigit = i;
-                }
-            }
-            else
-            {
-                // un-highlight the previous digit if moved off it
-                if (m_DigitInfo[i].editmode)
-                {
-                    m_DigitInfo[i].editmode = false;
-                    m_DigitInfo[i].modified = true;
-                }
+                setActiveDigit(i);
             }
         }
-
-        updateCtrl(false);
     }
 }
 
 void CFreqCtrl::mousePressEvent(QMouseEvent *event)
 {
-    QPoint    pt = event->pos();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QPointF pt = event->localPos();
+#else
+    QPointF pt = event->position();
+#endif
     if (event->button() == Qt::LeftButton)
     {
         for (int i = m_DigStart; i < m_NumDigits; i++)
@@ -466,7 +486,11 @@ void CFreqCtrl::mousePressEvent(QMouseEvent *event)
 
 void CFreqCtrl::wheelEvent(QWheelEvent *event)
 {
-    QPoint    pt = event->pos();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    QPointF   pt = QPointF(event->pos());
+#else
+    QPointF   pt = event->position();
+#endif
     int       delta = m_InvertScrolling ? -event->angleDelta().y() : event->angleDelta().y();
     int       numDegrees = delta / 8;
     int       numSteps = numDegrees / 15;
@@ -822,8 +846,7 @@ void CFreqCtrl::moveCursorLeft()
 {
     if ((m_ActiveEditDigit >= 0) && (m_ActiveEditDigit < m_NumDigits - 1))
     {
-        cursor().setPos(mapToGlobal(m_DigitInfo[++m_ActiveEditDigit].dQRect.
-                                    center()));
+        setActiveDigit(m_ActiveEditDigit + 1);
     }
 }
 
@@ -831,8 +854,7 @@ void CFreqCtrl::moveCursorRight()
 {
     if (m_ActiveEditDigit > m_FirstEditableDigit)
     {
-        cursor().setPos(mapToGlobal(m_DigitInfo[--m_ActiveEditDigit].dQRect.
-                                    center()));
+        setActiveDigit(m_ActiveEditDigit - 1);
     }
 }
 
@@ -840,8 +862,7 @@ void CFreqCtrl::cursorHome()
 {
     if (m_ActiveEditDigit >= 0)
     {
-        cursor().setPos(mapToGlobal(
-                            m_DigitInfo[m_NumDigits - 1].dQRect.center()));
+        setActiveDigit(m_NumDigits - 1);
     }
 }
 
@@ -849,20 +870,18 @@ void CFreqCtrl::cursorEnd()
 {
     if (m_ActiveEditDigit > 0)
     {
-        cursor().setPos(mapToGlobal(m_DigitInfo[m_FirstEditableDigit].dQRect.
-                                    center()));
+        setActiveDigit(m_FirstEditableDigit);
     }
 }
 
 void CFreqCtrl::setFrequencyFocus()
 {
-    uint8_t position = floor(log10(m_freq));
-    position = (uint8_t)fmax(position, 4);      // restrict min to 100s of kHz
+    // Select last digit or 5th digit (100s of kHz), whatever is bigger.
+    int position = std::max(int(log10(m_freq)), 5);
 
-    QMouseEvent mouseEvent(QEvent::MouseMove,
-                           m_DigitInfo[position].dQRect.center(),
-                           Qt::NoButton,
-                           Qt::NoButton,
-                           Qt::NoModifier);
-    mouseMoveEvent(&mouseEvent);
+    if (!hasFocus()) {
+        setFocus(Qt::ShortcutFocusReason);
+    }
+
+    setActiveDigit(position);
 }
